@@ -6,7 +6,7 @@ Swagger2 - Swagger RESTful API Documentation
 
 =head1 VERSION
 
-0.37
+0.38
 
 =head1 DESCRIPTION
 
@@ -63,7 +63,7 @@ use constant CACHE_DIR => $ENV{SWAGGER2_CACHE_DIR}
 
 use constant DEBUG => $ENV{SWAGGER2_DEBUG} || 0;
 
-our $VERSION = '0.37';
+our $VERSION = '0.38';
 
 # Should be considered internal
 our @SPEC_FILE = (File::Spec->splitdir(File::Basename::dirname(__FILE__)), 'Swagger2', 'schema.json');
@@ -228,10 +228,10 @@ but parse the text as JSON if it starts with "{".
 =cut
 
 sub parse {
-  my ($self, $doc) = @_;
-  my $namespace = 'http://127.0.0.1/#';
+  my ($self, $doc, $namespace) = @_;
 
   delete $self->{base_url};
+  $namespace ||= 'http://127.0.0.1/#';
   $self->{url} = Mojo::URL->new($namespace);
   $self->{tree} = $self->_parse($doc, undef, $namespace);
   $self;
@@ -345,7 +345,7 @@ sub _expand {
 
 sub _load {
   my ($self, $url) = @_;
-  my $namespace = $url->clone->fragment(undef);
+  my $namespace = $url->clone->fragment(undef)->port(undef);
   my $scheme = $url->scheme || 'file';
 
   # already loaded into memory
@@ -361,13 +361,13 @@ sub _load {
   # load spec from disk or web
   if (!$doc) {
     if ($scheme eq 'file') {
-      warn "[Swagger2] Loading $namespace ($url)\n" if DEBUG;
+      warn "[Swagger2] Loading $url ($namespace)\n" if DEBUG;
       $doc = Mojo::Util::slurp(File::Spec->catfile(split '/', $url->path));
       $type = lc $1 if $url->path =~ /\.(yaml|json)$/i;
     }
     else {
-      warn "[Swagger2] Fetching $namespace ($url)\n" if DEBUG;
-      my $tx = $self->ua->get($namespace);
+      warn "[Swagger2] Fetching $url ($namespace)\n" if DEBUG;
+      my $tx = $self->ua->get($url);
       $doc  = $tx->res->body;
       $type = lc $1 if $url->path =~ /\.(\w+)$/;
       $type = lc $1 if +($tx->res->headers->content_type // '') =~ /(json|yaml)/i;
